@@ -2,7 +2,7 @@
 
 // Test AxB_dot3_cuda kernels 
 // Using data generators and test classes, cover
-// all 12 cases for the masked GEMM ( C, M, A, B) in GraphBLAS
+// all NBUCKETS cases for the masked GEMM ( C, M, A, B) in GraphBLAS
 // Tests Semirings, data types and a range of data input sizes and shapes
 // Connects to the jitFactory for launches.
 
@@ -11,7 +11,9 @@
 #include <random>
 #include <algorithm>
 #include <cstdint>
+#include "problem_spec.hpp"
 #include "jitTestFactory.hpp"
+#include "../GB_cuda_buckets.h"
 
 //Test instances and groupings
 
