@@ -196,6 +196,7 @@ classdef GrB
 %   C = coth (G)            hyperbolic cotangent
 %   C = csc (G)             cosecant
 %   C = csch (G)            hyperbolic cosecant
+%   C = cbrt (G)            cube root
 %
 %   C = diag (A, k)         diagonal matrices and diagonals
 %   DiGraph = digraph (G,...)   directed Graph
@@ -567,8 +568,8 @@ classdef GrB
 %
 % See also sparse.
 %
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 properties (SetAccess = private, GetAccess = private)
     % The struct contains the entire opaque content of a GraphBLAS
@@ -834,6 +835,7 @@ methods
     C = coth (G) ;
     C = csc (G) ;
     C = csch (G) ;
+    C = cbrt (G) ;
 
     C = diag (A, k) ;
     DiGraph = digraph (G, option) ;
@@ -917,7 +919,7 @@ methods
 
     C = real (G) ;
     C = repmat (G, m, n) ;
-    C = reshape (G, arg1, arg2) ;
+    C = reshape (G, m, n, by_col) ;
     C = round (G) ;
 
     C = sec (G) ;
@@ -1039,6 +1041,8 @@ methods (Static)
     v = ver ;
     C = vreduce (Cin, M, accum, monoid, A, desc) ;
 
+    t = timing (c) ; % timing for diagnositics only, requires -DGB_TIMING
+
     % these were formerly overloaded methods, now Static methods
     C = false (varargin) ;
     C = true (varargin) ;
