@@ -36,7 +36,7 @@ function C = bitget (A, B, assumedtype)
 % GrB/bitset, GrB/bitclr.
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 if (nargin < 3)
     assumedtype = 'uint64' ;
@@ -54,15 +54,15 @@ atype = gbtype (A) ;
 btype = gbtype (B) ;
 
 if (gb_contains (atype, 'complex') || gb_contains (btype, 'complex'))
-    error ('inputs must be real') ;
+    error ('GrB:error', 'inputs must be real') ;
 end
 
 if (isequal (atype, 'logical') || isequal (btype, 'logical'))
-    error ('inputs must not be logical') ;
+    error ('GrB:error', 'inputs must not be logical') ;
 end
 
 if (~gb_contains (assumedtype, 'int'))
-    error ('assumedtype must be an integer type') ;
+    error ('GrB:error', 'assumedtype must be an integer type') ;
 end
 
 % C will have the same type as A on input
