@@ -5,13 +5,13 @@ function C = erf (G)
 %
 % See also GrB/erfc, erfcx, erfinv, erfcinv.
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 G = G.opaque ;
 type = gbtype (G) ;
 if (gb_contains (type, 'complex'))
-    error ('input must be real') ;
+    error ('GrB:error', 'input must be real') ;
 end
 if (~gb_isfloat (type))
     op = 'erf.double' ;
