@@ -27,7 +27,7 @@ function L = laplacian (A, type, check)
 % See also graph/laplacian.
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 if (isobject (A))
     A = A.opaque ;
@@ -35,7 +35,7 @@ end
 
 [m, n] = gbsize (A) ;
 if (m ~= n)
-    error ('A must be square and symmetric') ;
+    error ('GrB:error', 'A must be square and symmetric') ;
 end
 
 % get the type
@@ -43,7 +43,7 @@ if (nargin < 2)
     type = 'double' ;
 elseif (~gb_issigned (type))
     % type must be signed
-    error ('type cannot be logical or unsigned integer') ;
+    error ('GrB:error', 'type cannot be logical or unsigned integer') ;
 end
 
 % S = spones (A)
@@ -53,7 +53,7 @@ S = gbapply (['1.' type], A) ;
 if (nargin > 2 && isequal (check, 'check'))
     % make sure spones (S) is symmetric
     if (~gb_issymmetric (S, 'nonskew', false))
-        error ('spones(A) must be symmetric') ;
+        error ('GrB:error', 'spones(A) must be symmetric') ;
     end
 end
 
