@@ -4,11 +4,11 @@ function C = gb_expand (scalar, S, type)
 % first input is a scalar; the caller has checked this already.
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
-% typecast the scalar to the desired type
-scalar = gbnew (scalar, type) ;
+% typecast the scalar to the desired type, and make sure it's full
+scalar = gbfull (gbnew (scalar, type)) ;
 
 % expand the scalar into the pattern of S
-C = gbapply2 (['1st.' type], scalar, S) ;
+C = gbapply2 (['2nd.' type], S, scalar) ;
 
