@@ -3,7 +3,7 @@ function C = gb_min3 (op, A, option)
 % Implements C = min (A, [ ], option)
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 if (isequal (option, 'all'))
     % C = min (A, [ ] 'all'), reducing all entries to a scalar
@@ -19,7 +19,7 @@ else
         % giving an m-by-1 column vector.
         C = gb_minbyrow (op, A) ;
     else
-        error ('invalid option') ;
+        error ('GrB:error', 'invalid option') ;
     end
 end
 
