@@ -2,8 +2,8 @@ function C = gb_minbycol (op, A)
 %GB_MINBYCOL min, by column
 % Implements C = min (A, [ ], 1)
 
-% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
+% SPDX-License-Identifier: Apache-2.0
 
 % C = min (A, [ ], 1) reduces each col to a scalar; C is 1-by-n
 desc.in0 = 'transpose' ;
@@ -22,7 +22,7 @@ ctype = gbtype (C) ;
         % all columns A(:,j) have between 1 and m-1 entries
         C = gbapply2 (op, C, zero) ;
     else
-        d = gbapply2 (['1st.' ctype], zero, d) ;
+        d = gbapply2 (['2nd.' ctype], d, zero) ;
         % if d (j) is between 1 and m-1 and C (j) > 0 then C (j) = 0
         C = gbeadd (op, C, d) ;
     end
