@@ -3,7 +3,7 @@ function C = gb_prod (op, type, G, option)
 % Implements C = prod (G) and C = all (G).
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 [m, n] = gbsize (G) ;
 
@@ -51,7 +51,7 @@ switch (option)
 
     otherwise
 
-        error ('unknown option') ;
+        error ('GrB:error', 'unknown option') ;
 end
 
 
