@@ -3,7 +3,7 @@
 //------------------------------------------------------------------------------
 
 // SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
 
@@ -151,11 +151,7 @@ void mexFunction
     //--------------------------------------------------------------------------
 
     GrB_Index gnvals ;
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    OK1 (G, GrB_Matrix_wait (&G)) ;
-    #else
     OK1 (G, GrB_Matrix_wait (G, GrB_MATERIALIZE)) ;
-    #endif
     OK (GrB_Matrix_nvals (&gnvals, G)) ;
     OK (GxB_Matrix_Option_get (G, GxB_SPARSITY_STATUS, &sparsity)) ;
     CHECK_ERROR (sparsity == GxB_BITMAP, "internal error 0") ;
@@ -223,11 +219,7 @@ void mexFunction
     //--------------------------------------------------------------------------
 
     GrB_Index tnvals ;
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    OK1 (T, GrB_Matrix_wait (&T)) ;
-    #else
     OK1 (T, GrB_Matrix_wait (T, GrB_MATERIALIZE)) ;
-    #endif
     OK (GrB_Matrix_nvals (&tnvals, T)) ;
     uint64_t *Tx = T->x ;
     size_t Tx_size = T->x_size ;
@@ -283,6 +275,7 @@ void mexFunction
     int64_t *Vp = V->p ;
     Vp [0] = 0 ;
     Vp [1] = tnvals ;
+    V->nvals = tnvals ;
     V->magic = GB_MAGIC ;
     V->nvec_nonempty = (tnvals > 0) ? 1 : 0 ;
 
