@@ -22,7 +22,7 @@ function gbtest
 % See also GrB.
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 % gbtest3 requires ../demo/dnn_builtin.m and ../demo/dnn_builtin2gb.m.
 demo_folder = fullfile (fileparts (mfilename ('fullpath')), '../demo') ;
@@ -171,6 +171,9 @@ gbtest116 % test GrB.binopinfo for index_unary operators
 gbtest117 % test idxunop in GrB.apply2
 gbtest118 % test GrB.argsort
 gbtest119 % test GrB.eunion
+gbtest120 % test subsref
+gbtest121 % test times with scalars
+gbtest122 % test reshape
 gbtest96  % test GrB.optype
 
 if (~have_octave)
