@@ -2,7 +2,7 @@ function gbtest20
 %GBTEST20 test bandwidth, isdiag, ceil, floor, round, fix
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 rng ('default') ;
 for trial = 1:10
@@ -28,5 +28,11 @@ for trial = 1:10
     end
 end
 
+n = 2^60 ;
+G = GrB (n, n) ;
+G (n,1) = 1
+[lo, hi] = bandwidth (G)
+assert (lo == int64 (2^60) - 1)
+
 fprintf ('\ngbtest20: all tests passed\n') ;
 
