@@ -2,16 +2,18 @@ function gbtest52
 %GBTEST52 test GrB.format
 
 % SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
-% SPDX-License-Identifier: GPL-3.0-or-later
+% SPDX-License-Identifier: Apache-2.0
 
 GrB.format
 GrB.format ('by col') ;
 f = GrB.format %#ok<*NOPRT>
+assert (isequal (f, 'by col')) ;
 A = magic (4)
 G = GrB (A)
 assert (isequal (f, GrB.format (G))) ;
 GrB.format ('by row')
 f = GrB.format %#ok<*NASGU>
+assert (isequal (f, 'by row')) ;
 
 H = GrB (5,5)
 assert (isequal ('by row', GrB.format (H))) ;
@@ -24,6 +26,7 @@ assert (isequal ('by col', GrB.format (H))) ;
 
 GrB.format ('by col')
 f = GrB.format
+assert (isequal (f, 'by col')) ;
 
 H = GrB (5,5)
 assert (isequal ('by col', GrB.format (H))) ;
