@@ -9,6 +9,7 @@
 
 #include "GB_mxm.h"
 #include "GB_bitmap_AxB_saxpy.h"
+#include "GB_stringify.h"
 
 // TODO: allow bitmap multiply to work in-place as well
 
@@ -39,7 +40,7 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
 
     GrB_Info info ;
     (*mask_applied) = false ;
-    ASSERT (C != NULL && C->static_header) ;
+    ASSERT (C != NULL && (C->static_header || GBNSTATIC)) ;
 
     ASSERT_MATRIX_OK_OR_NULL (M, "M for saxpy A*B", GB0) ;
     ASSERT (!GB_PENDING (M)) ;
@@ -109,6 +110,12 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
             // atomically without a critical section are supported.  The method
             // is not used if A*B is iso; C may be iso on input but it is
             // non-iso on output.
+
+            #ifdef GB_DEBUGIFY_DEFN
+            GB_debugify_mxm (C_iso, GB_sparsity (C_in), ztype, M,
+                Mask_struct, Mask_comp, semiring, flipxy, A, B) ;
+            #endif
+
             info = GB_AxB_saxpy4 (C_in, A, B, semiring, flipxy, done_in_place,
                 Context) ;
             if (info != GrB_NO_VALUE)
@@ -127,6 +134,12 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
             // Only built-in semirings are supported, except for the ANY
             // monoid.  Unlike GB_AxB_saxpy4, built-in monoids without their
             // own atomics (TIMES for complex) are supported.
+
+            #ifdef GB_DEBUGIFY_DEFN
+            GB_debugify_mxm (C_iso, GB_sparsity (C_in), ztype, M,
+                Mask_struct, Mask_comp, semiring, flipxy, A, B) ;
+            #endif
+
             info = GB_AxB_saxpy5 (C_in, A, B, semiring, flipxy, done_in_place,
                 Context) ;
             if (info != GrB_NO_VALUE)
@@ -176,7 +189,7 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
         GBURBLE ("(iso full saxpy) ") ;
         ASSERT (C_sparsity == GxB_FULL) ;
         // set C->iso = true    OK
-        info = GB_new_bix (&C, true,    // static header
+        info = GB_new_bix (&C, // existing header
             ztype, A->vlen, B->vdim, GB_Ap_null, true, GxB_FULL, false,
             GB_HYPER_SWITCH_DEFAULT, -1, 1, true, true, Context) ;
         if (info == GrB_SUCCESS)
@@ -201,6 +214,11 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
         // high enough so that the time to initialize the space.  C is sparse
         // or hypersparse.
 
+        #ifdef GB_DEBUGIFY_DEFN
+        GB_debugify_mxm (C_iso, C_sparsity, ztype, M,
+            Mask_struct, Mask_comp, semiring, flipxy, A, B) ;
+        #endif
+
         ASSERT (C_sparsity == GxB_HYPERSPARSE || C_sparsity == GxB_SPARSE) ;
         info = GB_AxB_saxpy3 (C, C_iso, cscalar, C_sparsity, M, Mask_comp,
             Mask_struct, A, B, semiring, flipxy, mask_applied, AxB_method,
@@ -242,6 +260,12 @@ GrB_Info GB_AxB_saxpy               // C = A*B using Gustavson/Hash/Bitmap
         }
         else
         { 
+
+            #ifdef GB_DEBUGIFY_DEFN
+            GB_debugify_mxm (C_iso, GxB_BITMAP, ztype, M,
+                Mask_struct, Mask_comp, semiring, flipxy, A, B) ;
+            #endif
+
             // C<#M> = A*B via bitmap saxpy method
             info = GB_bitmap_AxB_saxpy (C, C_iso, cscalar, M,
                 Mask_comp, Mask_struct, A, B, semiring, flipxy, Context) ;
