@@ -10,6 +10,9 @@
 // This method construct a shallow statically-defined scalar, with no memory
 // allocations.  The scalar is iso full, with a single entry.
 
+// Note that since the header is statically allocated, it cannot be transfered
+// automatically to the GPU when using CUDA.
+
 #include "GB.h"
 #include "GB_scalar.h"
 
@@ -50,6 +53,9 @@ GrB_Scalar GB_Scalar_wrap   // create a new GrB_Scalar with one entry
     s->i = NULL ; s->i_size = 0 ; s->i_shallow = false ;
     s->x = Sx   ; s->x_size = type->size ; s->x_shallow = true ;
 
+    s->Y = NULL ;
+    s->Y_shallow = false ;
+
     s->nvals = 0 ;
 
     s->Pending = NULL ;
