@@ -31,7 +31,8 @@
 #include "GB_binop.h"
 #include "GB_unused.h"
 #include "GB_ek_slice.h"
-#ifndef GBCOMPACT
+#include "GB_stringify.h"
+#ifndef GBCUDA_DEV
 #include "GB_binop__include.h"
 #endif
 
@@ -47,7 +48,7 @@
 #define GB_FREE_ALL                 \
 {                                   \
     GB_FREE_WORKSPACE ;             \
-    GB_phbix_free (C) ;             \
+    GB_phybix_free (C) ;            \
 }
 
 GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
@@ -125,8 +126,9 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
     bool op_is_second = (opcode == GB_SECOND_binop_code) ;
     bool op_is_pair   = (opcode == GB_PAIR_binop_code) ;
 
+#ifdef GB_DEBUG
     if (op == NULL)
-    { 
+    {
         // GB_wait does no typecasting.  A and T have the same type when
         // computing A=A+T, and no operator is used since A and T have disjoint
         // nonzero patterns.  No mask is used.
@@ -136,15 +138,23 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
         ASSERT (C_is_sparse_or_hyper) ;
     }
     else
-    { 
-        ASSERT (GB_Type_compatible (ctype, A->type)) ;
-        ASSERT (GB_Type_compatible (ctype, B->type)) ;
+    {
+        // assert that the op is compatible with A, B, and C
+        if (!(GB_as_if_full (A) && GB_as_if_full (B)))
+        {
+            // eWiseMult uses GB_add when A and B are both as-if-full,
+            // and in this case, the entries of A and B are never typecasted
+            // directly to C.
+            ASSERT (GB_Type_compatible (ctype, A->type)) ;
+            ASSERT (GB_Type_compatible (ctype, B->type)) ;
+        }
         ASSERT (GB_Type_compatible (ctype, op->ztype)) ;
         ASSERT (GB_IMPLIES (!(op_is_second || op_is_pair || op_is_positional),
                 GB_Type_compatible (A->type, op->xtype))) ;
         ASSERT (GB_IMPLIES (!(op_is_first  || op_is_pair || op_is_positional),
                 GB_Type_compatible (B->type, op->ytype))) ;
     }
+#endif
 
     //--------------------------------------------------------------------------
     // get the typecasting functions
@@ -159,7 +169,7 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
 
     if (op == NULL)
     { 
-        // implicit GB_SECOND_[type] operator with no typecasting
+        // GB_wait: implicit GB_SECOND_[type] operator with no typecasting
         ASSERT (!is_eWiseUnion) ;
         fadd = NULL ;               // the operator is not called
         asize = csize ;
@@ -240,6 +250,11 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
     bool C_iso = GB_iso_add (cscalar, ctype, A, alpha_scalar,
         B, beta_scalar, op, is_eWiseUnion) ;
 
+    #ifdef GB_DEBUGIFY_DEFN
+    GB_debugify_ewise (C_iso, C_sparsity, ctype, M,
+        Mask_struct, Mask_comp, op, false, A, B) ;
+    #endif
+
     //--------------------------------------------------------------------------
     // allocate the output matrix C: hypersparse, sparse, bitmap, or full
     //--------------------------------------------------------------------------
@@ -270,6 +285,7 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
         C->nvec_nonempty = Cnvec_nonempty ;
         C->p = (int64_t *) Cp ; C->p_size = Cp_size ;
         (*Cp_handle) = NULL ;
+        C->nvals = cnz ;
     }
 
     // add Ch as the hypersparse list for C, from GB_add_phase0
@@ -318,7 +334,7 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
         // C is non-iso
         //----------------------------------------------------------------------
 
-        #ifndef GBCOMPACT
+        #ifndef GBCUDA_DEV
 
             //------------------------------------------------------------------
             // define the worker for the switch factory
@@ -369,7 +385,7 @@ GrB_Info GB_add_phase2      // C=A+B, C<M>=A+B, or C<!M>=A+B
     if (!done)
     {
         GB_BURBLE_MATRIX (C, "(generic add: %s) ",
-            (op == NULL) ? "second" : op->name) ;
+            (op == NULL) ? "2nd" : op->name) ;
 
         // C(i,j) = (ctype) A(i,j), located in Ax [pA]
         #undef  GB_COPY_A_TO_C 
