@@ -26,16 +26,13 @@ bool GB_binop_builtin               // true if binary operator is builtin
     GB_Type_code *zcode             // type code for z output
 ) ;
 
-GB_Opcode GB_flip_binop_code    // flipped binary opcode, or -1 on error
-(
-    GB_Opcode opcode,       // binary opcode to flip
-    bool *handled           // true if opcode is handled by flipping the opcode
-) ;
-
-GrB_BinaryOp GB_flip_op     // flip a binary operator, or NULL on error
+GrB_BinaryOp GB_flip_binop  // flip a binary operator
 (
+    // input:
     GrB_BinaryOp op,        // binary operator to flip
-    bool *handled           // true if operator is handled
+    bool for_ewise,         // if true: flip for eWise, else for semiring
+    // input/output:
+    bool *flipxy            // true on input, set to false if op is flipped
 ) ;
 
 GB_PUBLIC
@@ -49,7 +46,7 @@ GrB_BinaryOp GB_boolean_rename_op   // return renamed op
     const GrB_BinaryOp op           // op to rename
 ) ;
 
-void GB_binop_new
+GrB_Info GB_binop_new
 (
     GrB_BinaryOp op,                // new binary operator
     GxB_binary_function function,   // binary function (may be NULL)
