@@ -9,7 +9,7 @@
 
 #define GB_FREE_ALL                 \
 {                                   \
-    GB_phbix_free (C) ;             \
+    GB_phybix_free (C) ;            \
     GB_FREE (&Cp, Cp_size) ;        \
     GB_FREE (&Ch, Ch_size) ;        \
     GB_FREE (&Ci, Ci_size) ;        \
@@ -172,7 +172,7 @@ GrB_Info GB_bitmap_expand_to_hyper
     C->nzombies = (C_is_bitmap) ? (cnz - C->nvals) : 0 ;
     C->vdim = cvdim_final ;
     C->vlen = cvlen_final ;
-    C->nvals = -1 ;
+    C->nvals = cnz ;
     C->nvec = cvdim ;
     C->plen = cvdim ;
     C->nvec_nonempty = (cvlen == 0) ? 0 : cvdim ;
