@@ -23,13 +23,14 @@ GrB_Info GB_block   // apply all pending computations if blocking mode enabled
     // check inputs
     //--------------------------------------------------------------------------
 
+    GrB_Info info ;
     ASSERT (A != NULL) ;
 
     //--------------------------------------------------------------------------
     // wait if mode is blocking, or if too many pending tuples
     //--------------------------------------------------------------------------
 
-    if (!GB_ANY_PENDING_WORK (A))
+    if (!(GB_ANY_PENDING_WORK (A) || GB_NEED_HYPER_HASH (A)))
     { 
         // no pending work, so no need to block
         return (GrB_SUCCESS) ;
@@ -38,12 +39,15 @@ GrB_Info GB_block   // apply all pending computations if blocking mode enabled
     double npending = (double) GB_Pending_n (A) ;
     double anzmax = ((double) A->vlen) * ((double) A->vdim) ;
     bool many_pending = (npending >= anzmax) ;
-    bool blocking = (GB_Global_mode_get ( ) == GrB_BLOCKING) ;
+    GrB_Mode mode = GB_Global_mode_get ( ) ;
+    bool blocking = (mode == GrB_BLOCKING || mode == GxB_BLOCKING_GPU) ;
 
     if (many_pending || blocking)
     { 
-        // delete any lingering zombies and assemble any pending tuples
-        GB_MATRIX_WAIT (A) ;
+        // delete any lingering zombies, assemble any pending tuples,
+        // sort the vectors, and construct the A->Y hyper_hash
+        GB_OK (GB_wait (A, "matrix", Context)) ;
+        GB_OK (GB_hyper_hash_build (A, Context)) ;
     }
     return (GrB_SUCCESS) ;
 }
