@@ -94,8 +94,8 @@
 
 // The input arrays I, J, and X are not modified.
 
+#define GB_FREE_ALL GrB_Matrix_free (&T) ;
 #include "GB_build.h"
-#define GB_FREE_ALL GB_phbix_free (T) ;
 
 GrB_Info GB_build               // build matrix
 (
@@ -244,7 +244,7 @@ GrB_Info GB_build               // build matrix
 
     // the type, dimensions, hyper_switch, bitmap_switch and sparsity control
     // are still preserved in C.
-    GB_phbix_free (C) ;
+    GB_phybix_free (C) ;
 
     //--------------------------------------------------------------------------
     // build the matrix T
@@ -262,7 +262,8 @@ GrB_Info GB_build               // build matrix
     int64_t *no_J_work = NULL ; size_t J_work_size = 0 ;
     GB_void *no_X_work = NULL ; size_t X_work_size = 0 ;
     struct GB_Matrix_opaque T_header ;
-    GrB_Matrix T = GB_clear_static_header (&T_header) ;
+    GrB_Matrix T = NULL ;
+    GB_CLEAR_STATIC_HEADER (T, &T_header) ;
     GrB_Type ttype = (discard_duplicates) ? xtype : dup->ztype ;
 
     GB_OK (GB_builder (
@@ -288,6 +289,7 @@ GrB_Info GB_build               // build matrix
         nvals,          // number of tuples
         dup2,           // operator to assemble duplicates (may be NULL)
         xtype,          // type of the X array
+        true,           // burble is OK
         Context
     )) ;
 
