@@ -13,7 +13,7 @@
 // iso expansion is done.
 
 #include "GB.h"
-#ifndef GBCOMPACT
+#ifndef GBCUDA_DEV
 #include "GB_unop__include.h"
 #endif
 
@@ -52,7 +52,7 @@ void GB_cast_array              // typecast an array
     // typecast the array
     //--------------------------------------------------------------------------
 
-    #ifndef GBCOMPACT
+    #ifndef GBCUDA_DEV
 
         //----------------------------------------------------------------------
         // define the worker for the switch factory
@@ -79,7 +79,7 @@ void GB_cast_array              // typecast an array
     #endif
 
     //--------------------------------------------------------------------------
-    // generic worker: only used for GBCOMPACT case
+    // generic worker: only used for GBCUDA_DEV case
     //--------------------------------------------------------------------------
 
     int64_t csize = GB_code_size (code1, 0) ;
