@@ -10,6 +10,14 @@
 #ifndef GB_COMPILER_H
 #define GB_COMPILER_H
 
+#define GB_COMPILER_NVCC    0
+#define GB_COMPILER_ICX     0
+#define GB_COMPILER_ICC     0
+#define GB_COMPILER_CLANG   0
+#define GB_COMPILER_GCC     0
+#define GB_COMPILER_MSC     0
+#define GB_COMPILER_XLC     0
+
 //------------------------------------------------------------------------------
 // determine which compiler is in use
 //------------------------------------------------------------------------------
@@ -17,14 +25,8 @@
 #if defined ( __NVCC__ )
 
     // NVIDIA nvcc compiler
+    #undef  GB_COMPILER_NVCC
     #define GB_COMPILER_NVCC    1
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR __CUDACC_VER_MAJOR__
     #define GB_COMPILER_MINOR __CUDACC_VER_MINOR__
@@ -34,14 +36,8 @@
 #elif defined ( __INTEL_CLANG_COMPILER )
 
     // Intel icx compiler, 2022.0.0 based on clang/llvm 14.0.0
-    #define GB_COMPILER_NVCC    0
+    #undef  GB_COMPILER_ICX
     #define GB_COMPILER_ICX     1
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR __INTEL_CLANG_COMPILER
     #define GB_COMPILER_MINOR 0
@@ -51,14 +47,8 @@
 #elif defined ( __INTEL_COMPILER )
 
     // Intel icc compiler: 2021.5.0 uses "gcc 7.5 mode"
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
+    #undef  GB_COMPILER_ICC
     #define GB_COMPILER_ICC     1
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR __INTEL_COMPILER
     #define GB_COMPILER_MINOR __INTEL_COMPILER_UPDATE
@@ -68,14 +58,8 @@
 #elif defined ( __clang__ )
 
     // clang
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
+    #undef  GB_COMPILER_CLANG
     #define GB_COMPILER_CLANG   1
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR __clang_major__
     #define GB_COMPILER_MINOR __clang_minor__
@@ -85,14 +69,8 @@
 #elif defined ( __xlC__ )
 
     // xlc
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
+    #undef  GB_COMPILER_XLC
     #define GB_COMPILER_XLC     1
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR ( __xlC__ / 256 )
     #define GB_COMPILER_MINOR ( __xlC__ - 256 * GB_COMPILER_MAJOR)
@@ -102,14 +80,8 @@
 #elif defined ( __GNUC__ )
 
     // gcc
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
+    #undef  GB_COMPILER_GCC
     #define GB_COMPILER_GCC     1
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR __GNUC__
     #define GB_COMPILER_MINOR __GNUC_MINOR__
@@ -119,55 +91,18 @@
 
 #elif defined ( _MSC_VER )
 
-    // Microsoft Visual Studio
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
+    // Microsoft Visual Studio (cl compiler)
+    #undef  GB_COMPILER_MSC
     #define GB_COMPILER_MSC     1
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
 
     #define GB_COMPILER_MAJOR ( _MSC_VER / 100 )
     #define GB_COMPILER_MINOR ( _MSC_VER - 100 * GB_COMPILER_MAJOR)
     #define GB_COMPILER_SUB   0
     #define GB_COMPILER_NAME  "Microsoft Visual Studio " GB_XSTR (_MSC_VER)
 
-#elif defined ( __MINGW32__ ) || defined ( __MINGW64__ )
-
-    // MinGW (32-bit or 64-bit)
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   1
-
-    #if defined ( __MINGW32__ )
-    #define GB_COMPILER_MAJOR ( __MINGW32_MAJOR_VERSION )
-    #define GB_COMPILER_MINOR ( __MINGW32_MINOR_VERSION )
-    #else
-    #define GB_COMPILER_MAJOR ( __MINGW64_MAJOR_VERSION )
-    #define GB_COMPILER_MINOR ( __MINGW64_MINOR_VERSION )
-    #endif
-    #define GB_COMPILER_SUB   0
-    #define GB_COMPILER_NAME  "MinGW"
-
 #else
 
     // other compiler
-    #define GB_COMPILER_NVCC    0
-    #define GB_COMPILER_ICX     0
-    #define GB_COMPILER_ICC     0
-    #define GB_COMPILER_CLANG   0
-    #define GB_COMPILER_GCC     0
-    #define GB_COMPILER_MSC     0
-    #define GB_COMPILER_XLC     0
-    #define GB_COMPILER_MINGW   0
-
     #define GB_COMPILER_MAJOR 0
     #define GB_COMPILER_MINOR 0
     #define GB_COMPILER_SUB   0
@@ -175,6 +110,17 @@
 
 #endif
 
+//------------------------------------------------------------------------------
+// MINGW system, for Windows
+//------------------------------------------------------------------------------
+
+#if defined ( __MINGW32__ )
+    // MinGW (32-bit or 64-bit): using gcc, clang, or other compilers.
+    #define GB_MINGW   1
+#else
+    #define GB_MINGW   0
+#endif
+
 //------------------------------------------------------------------------------
 // Workaround for compiler bug in Microsoft Visual Studio 2019
 //------------------------------------------------------------------------------
