@@ -28,7 +28,6 @@ GrB_Info GB_convert_full_to_sparse      // convert matrix from full to sparse
     ASSERT (!GB_ZOMBIES (A)) ;
     ASSERT (!GB_JUMBLED (A)) ;
     ASSERT (!GB_PENDING (A)) ;
-    GBURBLE ("(full to sparse) ") ;
 
     //--------------------------------------------------------------------------
     // allocate A->p and A->i
@@ -37,6 +36,7 @@ GrB_Info GB_convert_full_to_sparse      // convert matrix from full to sparse
     int64_t avdim = A->vdim ;
     int64_t avlen = A->vlen ;
     int64_t anz = GB_nnz_full (A) ;
+    GB_BURBLE_N (anz, "(full to sparse) ") ;
     int64_t *restrict Ap = NULL ; size_t Ap_size = 0 ;
     int64_t *restrict Ai = NULL ; size_t Ai_size = 0 ;
     Ap = GB_MALLOC (avdim+1, int64_t, &Ap_size) ;
@@ -54,6 +54,7 @@ GrB_Info GB_convert_full_to_sparse      // convert matrix from full to sparse
     A->plen = avdim ;
     A->nvec = avdim ;
     A->nvec_nonempty = (avlen == 0) ? 0 : avdim ;
+    A->nvals = anz ;
 
     //--------------------------------------------------------------------------
     // determine the number of threads to use
