@@ -11,7 +11,8 @@
 
 #include "GB_dense.h"
 #include "GB_binop.h"
-#ifndef GBCOMPACT
+#include "GB_stringify.h"
+#ifndef GBCUDA_DEV
 #include "GB_binop__include.h"
 #endif
 
@@ -24,7 +25,7 @@ void GB_dense_ewise3_accum          // C += A+B, all matrices dense
     GB_Context Context
 )
 {
-#ifndef GBCOMPACT
+#ifndef GBCUDA_DEV
 
     //--------------------------------------------------------------------------
     // check inputs
@@ -71,6 +72,11 @@ void GB_dense_ewise3_accum          // C += A+B, all matrices dense
 
     // FUTURE::: handle IS*, LOR, LAND, LXOR operators
 
+    #ifdef GB_DEBUGIFY_DEFN
+    GB_debugify_ewise (false, GxB_FULL, C->type, NULL,
+        false, false, op, false, A, B) ;
+    #endif
+
     //--------------------------------------------------------------------------
     // determine the number of threads to use
     //--------------------------------------------------------------------------
