@@ -75,9 +75,8 @@ GrB_Info GB_dup_worker      // make an exact copy of a matrix
     // allocate a new user header for C if (*Chandle) is NULL, or reuse the
     // existing static or dynamic header if (*Chandle) is not NULL.
     GrB_Matrix C = (*Chandle) ;
-    bool C_static_header = (C == NULL) ? false : C->static_header ;
     // set C->iso = C_iso   OK: burble in the caller
-    GB_OK (GB_new_bix (Chandle, C_static_header, // new/old/static header
+    GB_OK (GB_new_bix (Chandle, // can be new or existing header
         numeric ? atype : ctype, A->vlen, A->vdim, GB_Ap_malloc, A->is_csc,
         GB_sparsity (A), false, A->hyper_switch, A->plen, anz, true, C_iso,
         Context)) ;
@@ -89,7 +88,7 @@ GrB_Info GB_dup_worker      // make an exact copy of a matrix
 
     C->nvec = anvec ;
     C->nvec_nonempty = anvec_nonempty ;
-    C->nvals = anvals ;             // for bitmap only
+    C->nvals = anvals ;
     C->jumbled = A_jumbled ;        // C is jumbled if A is jumbled
     C->nzombies = A_nzombies ;      // zombies can be duplicated
     C->sparsity_control = sparsity_control ;
