@@ -17,9 +17,10 @@
 GrB_Info GB_hyper_prune
 (
     // output, not allocated on input:
-    int64_t *restrict *p_Ap, size_t *p_Ap_size,      // size nvec+1
-    int64_t *restrict *p_Ah, size_t *p_Ah_size,      // size nvec
+    int64_t *restrict *p_Ap, size_t *p_Ap_size,      // size plen+1
+    int64_t *restrict *p_Ah, size_t *p_Ah_size,      // size plen
     int64_t *p_nvec,                // # of vectors, all nonempty
+    int64_t *p_plen,                // size of Ap and Ah
     // input, not modified
     const int64_t *Ap_old,          // size nvec_old+1
     const int64_t *Ah_old,          // size nvec_old
@@ -83,8 +84,9 @@ GrB_Info GB_hyper_prune
     // allocate the result
     //--------------------------------------------------------------------------
 
-    Ap = GB_MALLOC (nvec+1, int64_t, &Ap_size) ;
-    Ah = GB_MALLOC (nvec  , int64_t, &Ah_size) ;
+    int64_t plen = GB_IMAX (1, nvec) ;
+    Ap = GB_MALLOC (plen+1, int64_t, &Ap_size) ;
+    Ah = GB_MALLOC (plen  , int64_t, &Ah_size) ;
     if (Ap == NULL || Ah == NULL)
     { 
         // out of memory
@@ -119,6 +121,7 @@ GrB_Info GB_hyper_prune
     (*p_Ap) = Ap ; (*p_Ap_size) = Ap_size ;
     (*p_Ah) = Ah ; (*p_Ah_size) = Ah_size ;
     (*p_nvec) = nvec ;
+    (*p_plen) = plen ;
     return (GrB_SUCCESS) ;
 }
 
