@@ -98,7 +98,7 @@ GrB_Info GB_import      // import/pack a matrix in any format
         case GxB_HYPERSPARSE : 
             // check Ap and get nvals
             if (nvec > vdim) return (GrB_INVALID_VALUE) ;
-            if (Ap_size < (nvec+1) * sizeof (int64_t))
+            if (Ap_size < (((vdim == 1) ? 1 : nvec)+1) * sizeof (int64_t))
             { 
                 return (GrB_INVALID_VALUE) ;
             }
@@ -201,11 +201,12 @@ GrB_Info GB_import      // import/pack a matrix in any format
     if (packing)
     { 
         // clear the content and reuse the header
-        GB_phbix_free (*A) ;
+        GB_phybix_free (*A) ;
+        ASSERT (!((*A)->static_header)) ;
     }
 
     // also create A->p if this is a sparse GrB_Vector
-    GrB_Info info = GB_new (A, false, // any sparsity, new user header
+    GrB_Info info = GB_new (A, // any sparsity, new or existing user header
         type, vlen, vdim, is_sparse_vector ? GB_Ap_calloc : GB_Ap_null,
         is_csc, sparsity, GB_Global_hyper_switch_get ( ), nvec, Context) ;
     if (info != GrB_SUCCESS)
@@ -214,6 +215,9 @@ GrB_Info GB_import      // import/pack a matrix in any format
         return (info) ;
     }
 
+    // A never has a static header
+    ASSERT (!((*A)->static_header)) ;
+
     //--------------------------------------------------------------------------
     // import the matrix
     //--------------------------------------------------------------------------
@@ -238,10 +242,12 @@ GrB_Info GB_import      // import/pack a matrix in any format
                 #endif
                 GB_Global_memtable_add ((*A)->h, (*A)->h_size) ;
             }
+            // fall through to the sparse case
 
         case GxB_SPARSE : 
             (*A)->jumbled = jumbled ;   // import jumbled status
             (*A)->nvec_nonempty = -1 ;  // not computed; delay until required
+            (*A)->nvals = nvals ;
 
             if (is_sparse_vector)
             { 
