@@ -2,7 +2,7 @@
 // GB_is_shallow: determine if a GrB_matrix has any shallow components
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
@@ -25,7 +25,8 @@ bool GB_is_shallow              // true if any component of A is shallow
     { 
         // check if any component of A is shallow
         return (A->p_shallow || A->h_shallow || A->b_shallow ||
-                A->i_shallow || A->x_shallow) ;
+                A->i_shallow || A->x_shallow || A->Y_shallow ||
+                GB_is_shallow (A->Y)) ;
     }
 }
 
