@@ -11,23 +11,23 @@
 
 // The input matrices A and B are optionally transposed.
 
-#include "GB_kron.h"
-#include "GB_mxm.h"
-#include "GB_transpose.h"
-#include "GB_accum_mask.h"
-
 #define GB_FREE_WORKSPACE   \
 {                           \
-    GB_phbix_free (AT) ;    \
-    GB_phbix_free (BT) ;    \
+    GB_Matrix_free (&AT) ;  \
+    GB_Matrix_free (&BT) ;  \
 }
 
 #define GB_FREE_ALL         \
 {                           \
     GB_FREE_WORKSPACE ;     \
-    GB_phbix_free (T) ;     \
+    GB_Matrix_free (&T) ;   \
 }
 
+#include "GB_kron.h"
+#include "GB_mxm.h"
+#include "GB_transpose.h"
+#include "GB_accum_mask.h"
+
 GrB_Info GB_kron                    // C<M> = accum (C, kron(A,B))
 (
     GrB_Matrix C,                   // input/output matrix for results
@@ -53,9 +53,7 @@ GrB_Info GB_kron                    // C<M> = accum (C, kron(A,B))
 
     GrB_Info info ;
     struct GB_Matrix_opaque T_header, AT_header, BT_header ;
-    GrB_Matrix T  = GB_clear_static_header (&T_header) ;
-    GrB_Matrix AT = GB_clear_static_header (&AT_header) ;
-    GrB_Matrix BT = GB_clear_static_header (&BT_header) ;
+    GrB_Matrix T = NULL, AT = NULL, BT = NULL ;
     GrB_BinaryOp op = op_in ;
 
     GB_RETURN_IF_NULL_OR_FAULTY (C) ;
@@ -141,6 +139,7 @@ GrB_Info GB_kron                    // C<M> = accum (C, kron(A,B))
     { 
         // AT = A' and typecast to op->xtype
         GBURBLE ("(A transpose) ") ;
+        GB_CLEAR_STATIC_HEADER (AT, &AT_header) ;
         GB_OK (GB_transpose_cast (AT, op->xtype, T_is_csc, A, A_is_pattern,
             Context)) ;
         ASSERT_MATRIX_OK (AT, "AT kron", GB0) ;
@@ -150,6 +149,7 @@ GrB_Info GB_kron                    // C<M> = accum (C, kron(A,B))
     { 
         // BT = B' and typecast to op->ytype
         GBURBLE ("(B transpose) ") ;
+        GB_CLEAR_STATIC_HEADER (BT, &BT_header) ;
         GB_OK (GB_transpose_cast (BT, op->ytype, T_is_csc, B, B_is_pattern,
             Context)) ;
         ASSERT_MATRIX_OK (BT, "BT kron", GB0) ;
@@ -159,6 +159,7 @@ GrB_Info GB_kron                    // C<M> = accum (C, kron(A,B))
     // T = kron(A,B)
     //--------------------------------------------------------------------------
 
+    GB_CLEAR_STATIC_HEADER (T, &T_header) ;
     GB_OK (GB_kroner (T, T_is_csc, op,
         A_transpose ? AT : A, A_is_pattern,
         B_transpose ? BT : B, B_is_pattern, Context)) ;
