@@ -2,7 +2,7 @@
 // GB_make_shallow.c: force a matrix to have purely shallow components
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
@@ -19,7 +19,7 @@ GB_PUBLIC void GB (make_shallow) (GrB_Matrix A)
     A->i_shallow = (A->i != NULL) ;
     A->x_shallow = (A->x != NULL) ;
     #ifdef GB_MEMDUMP
-    printf ("remove from memtable: p:%p h:%p b:%p i:%p x:%p\n",
+    printf ("remove from memtable: Ap:%p Ah:%p Ab:%p Ai:%p Ax:%p\n",
         A->p, A->h, A->b, A->i, A->x) ;
     #endif
     if (A->p != NULL) GB_Global_memtable_remove (A->p) ;
@@ -27,5 +27,6 @@ GB_PUBLIC void GB (make_shallow) (GrB_Matrix A)
     if (A->b != NULL) GB_Global_memtable_remove (A->b) ;
     if (A->i != NULL) GB_Global_memtable_remove (A->i) ;
     if (A->x != NULL) GB_Global_memtable_remove (A->x) ;
+    GB (make_shallow) (A->Y) ;
 }
 
