@@ -14,7 +14,7 @@
 // memory management
 //------------------------------------------------------------------------------
 
-GrB_Info GB_memoryUsage     // count # allocated blocks and their sizes
+void GB_memoryUsage         // count # allocated blocks and their sizes
 (
     int64_t *nallocs,       // # of allocated memory blocks
     size_t *mem_deep,       // # of bytes in blocks owned by this matrix
@@ -121,7 +121,7 @@ void GB_memset                  // parallel memset
             printf ("dealloc (%s, line %d): %p size %lu\n", \
                 __FILE__, __LINE__, (*p), s) ; \
         } \
-        GB_dealloc_memory (p, s) ; \
+        GB_dealloc_memory ((void **) p, s) ; \
     }
 
     #define GB_CALLOC(n,type,s) \
