@@ -25,7 +25,8 @@
 #include "GB_reduce.h"
 #include "GB_binop.h"
 #include "GB_atomics.h"
-#ifndef GBCOMPACT
+#include "GB_stringify.h"
+#ifndef GBCUDA_DEV
 #include "GB_red__include.h"
 #endif
 
@@ -96,12 +97,16 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
     GB_void s [GB_VLA(zsize)] ;
     memcpy (s, reduce->identity, zsize) ;   // required, if nnz(A) is zero
 
+    #ifdef GB_DEBUGIFY_DEFN
+    GB_debugify_reduce (reduce, A) ;
+    #endif
+
     //--------------------------------------------------------------------------
     // s = reduce_to_scalar (A) on the GPU(s) or CPU
     //--------------------------------------------------------------------------
 
     #if defined ( GBCUDA )
-    if (!A->iso && GB_reduce_to_scalar_cuda_branch (reduce, A, Context))
+    if (GB_reduce_to_scalar_cuda_branch (reduce, A, Context))
     {
 
         //----------------------------------------------------------------------
@@ -176,7 +181,7 @@ GrB_Info GB_reduce_to_scalar    // s = reduce_to_scalar (A)
 
             bool done = false ;
 
-            #ifndef GBCOMPACT
+            #ifndef GBCUDA_DEV
 
                 //--------------------------------------------------------------
                 // define the worker for the switch factory
