@@ -10,14 +10,14 @@
 // C<M> = accum (C,reduce(A)) where C is n-by-1.  Reduces a matrix A or A'
 // to a vector.
 
+#define GB_FREE_ALL GB_Matrix_free (&B) ;
+
 #include "GB_reduce.h"
 #include "GB_binop.h"
 #include "GB_mxm.h"
 #include "GB_get_mask.h"
 #include "GB_Semiring_new.h"
 
-#define GB_FREE_ALL ;
-
 GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
 (
     GrB_Matrix C,                   // input/output for results, size n-by-1
@@ -35,7 +35,7 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     //--------------------------------------------------------------------------
 
     struct GB_Matrix_opaque B_header ;
-    GrB_Matrix B = GB_clear_static_header (&B_header) ;
+    GrB_Matrix B = NULL ;
 
     // C may be aliased with M and/or A
     GB_RETURN_IF_NULL_OR_FAULTY (C) ;
@@ -109,7 +109,8 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     // though it is m-by-1.  It contains no dynamically-allocated content and
     // does not need to be freed.
     int64_t m = A_transpose ? GB_NROWS (A) : GB_NCOLS (A) ;
-    info = GB_new (&B, true,  // full, static header
+    GB_CLEAR_STATIC_HEADER (B, &B_header) ;
+    info = GB_new (&B, // full, existing header
         ztype, m, 1, GB_Ap_null, true, GxB_FULL, GB_NEVER_HYPER, 1, Context) ;
     ASSERT (info == GrB_SUCCESS) ;
     B->magic = GB_MAGIC ;
@@ -126,11 +127,17 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     // create the FIRST_ZTYPE binary operator
     //--------------------------------------------------------------------------
 
-    // note the function pointer is NULL; it is not needed by FIRST
+    // Note the function pointer is NULL; it is not needed by FIRST.  The
+    // function defn is also NULL.  In the JIT, the FIRST multiply operator is
+    // a simple assignment so there's no need for a function definition.
+
     struct GB_BinaryOp_opaque op_header ;
     GrB_BinaryOp op = &op_header ;
-    GB_binop_new (op, NULL, ztype, ztype, ztype, "1st_ztype", NULL,
+    info = GB_binop_new (op, NULL, ztype, ztype, ztype, "1st", NULL,
         GB_FIRST_binop_code) ;
+
+    // GB_binop_new cannot fail since it doesn't allocate the function defn.
+    ASSERT (info == GrB_SUCCESS) ;
     ASSERT_BINARYOP_OK (op, "op for reduce-to-vector", GB0) ;
 
     //--------------------------------------------------------------------------
@@ -148,8 +155,10 @@ GrB_Info GB_reduce_to_vector        // C<M> = accum (C,reduce(A))
     // reduce the matrix to a vector via C<M> = accum (C, A*B)
     //--------------------------------------------------------------------------
 
-    return (GB_mxm (C, C_replace, M, Mask_comp, Mask_struct, accum,
+    info = GB_mxm (C, C_replace, M, Mask_comp, Mask_struct, accum,
         semiring, A, A_transpose, B, false, false, GxB_DEFAULT, do_sort,
-        Context)) ;
+        Context) ;
+    GB_FREE_ALL ;
+    return (info) ;
 }
 
