@@ -126,14 +126,15 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     // parse the method
     //--------------------------------------------------------------------------
 
-    bool intel ;
     int32_t algo, level ;
-    GB_serialize_method (&intel, &algo, &level, method) ;
-    method = (intel ? GxB_COMPRESSION_INTEL : 0) + (algo) + (level) ;
-    GBURBLE ("(compression: %s%s%s%s:%d) ", intel ? "Intel IPP:" : "",
+    GB_serialize_method (&algo, &level, method) ;
+    method = algo + level ;
+    GBURBLE ("(compression: %s%s%s%s:%d) ",
         (algo == GxB_COMPRESSION_NONE ) ? "none" : "",
         (algo == GxB_COMPRESSION_LZ4  ) ? "LZ4" : "",
-        (algo == GxB_COMPRESSION_LZ4HC) ? "LZ4HC" : "", level) ;
+        (algo == GxB_COMPRESSION_LZ4HC) ? "LZ4HC" : "",
+        (algo == GxB_COMPRESSION_ZSTD ) ? "ZSTD" : "",
+        level) ;
 
     //--------------------------------------------------------------------------
     // get the content of the matrix
@@ -155,7 +156,7 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     ASSERT (A->nzombies == 0) ;
     ASSERT (!A->jumbled) ;
     GrB_Type atype = A->type ;
-    size_t typesize = atype->size ;
+    int64_t typesize = atype->size ;
     int32_t typecode = (int32_t) (atype->code) ;
     int64_t anz = GB_nnz (A) ;
     int64_t anz_held = GB_nnz_held (A) ;
@@ -170,6 +171,7 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     {
         case GxB_HYPERSPARSE : 
             Ah_len = sizeof (GrB_Index) * nvec ;
+            // fall through to the sparse case
         case GxB_SPARSE :
             Ap_len = sizeof (GrB_Index) * (nvec+1) ;
             Ai_len = sizeof (GrB_Index) * anz ;
@@ -177,6 +179,7 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
             break ;
         case GxB_BITMAP : 
             Ab_len = sizeof (int8_t) * anz_held ;
+            // fall through to the full case
         case GxB_FULL : 
             Ax_len = typesize * (iso ? 1 : anz_held) ;
             break ;
@@ -195,27 +198,27 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     GB_OK (GB_serialize_array (&Ap_Blocks, &Ap_Blocks_size,
         &Ap_Sblocks, &Ap_Sblocks_size, &Ap_nblocks, &Ap_method,
         &Ap_compressed_size, dryrun,
-        (GB_void *) A->p, Ap_len, method, intel, algo, level, Context)) ;
+        (GB_void *) A->p, Ap_len, method, algo, level, Context)) ;
 
     GB_OK (GB_serialize_array (&Ah_Blocks, &Ah_Blocks_size,
         &Ah_Sblocks, &Ah_Sblocks_size, &Ah_nblocks, &Ah_method,
         &Ah_compressed_size, dryrun,
-        (GB_void *) A->h, Ah_len, method, intel, algo, level, Context)) ;
+        (GB_void *) A->h, Ah_len, method, algo, level, Context)) ;
 
     GB_OK (GB_serialize_array (&Ab_Blocks, &Ab_Blocks_size,
         &Ab_Sblocks, &Ab_Sblocks_size, &Ab_nblocks, &Ab_method,
         &Ab_compressed_size, dryrun,
-        (GB_void *) A->b, Ab_len, method, intel, algo, level, Context)) ;
+        (GB_void *) A->b, Ab_len, method, algo, level, Context)) ;
 
     GB_OK (GB_serialize_array (&Ai_Blocks, &Ai_Blocks_size,
         &Ai_Sblocks, &Ai_Sblocks_size, &Ai_nblocks, &Ai_method,
         &Ai_compressed_size, dryrun,
-        (GB_void *) A->i, Ai_len, method, intel, algo, level, Context)) ;
+        (GB_void *) A->i, Ai_len, method, algo, level, Context)) ;
 
     GB_OK (GB_serialize_array (&Ax_Blocks, &Ax_Blocks_size,
         &Ax_Sblocks, &Ax_Sblocks_size, &Ax_nblocks, &Ax_method,
         &Ax_compressed_size, dryrun,
-        (GB_void *) A->x, Ax_len, method, intel, algo, level, Context)) ;
+        (GB_void *) A->x, Ax_len, method, algo, level, Context)) ;
 
     //--------------------------------------------------------------------------
     // determine the size of the blob
@@ -295,7 +298,11 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     int32_t sparsity_iso_csc = (4 * sparsity) + (iso ? 2 : 0) +
         (A->is_csc ? 1 : 0) ;
 
-    GB_BLOB_WRITE (blob_size_required, size_t) ;
+    // size_t is 32 bits if GraphBLAS is compiled in ILP32 mode,
+    // so write a 64-bit blob size, regardless of the size of size_t
+    uint64_t blob_size_required64 = (uint64_t) blob_size_required ;
+    GB_BLOB_WRITE (blob_size_required64, uint64_t) ;
+
     GB_BLOB_WRITE (typecode, int32_t) ;
     GB_BLOB_WRITE (version, int32_t) ;
     GB_BLOB_WRITE (vlen, int64_t) ;
@@ -324,6 +331,11 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
     { 
         // only copy the type_name for user-defined types
         memset (blob + s, 0, GxB_MAX_NAME_LEN) ;
+        #if GB_COMPILER_GCC
+        #if (__GNUC__ > 5)
+        #pragma GCC diagnostic ignored "-Wstringop-truncation"
+        #endif
+        #endif
         strncpy ((char *) (blob + s), atype->name, GxB_MAX_NAME_LEN-1) ;
         s += GxB_MAX_NAME_LEN ;
     }
