@@ -24,7 +24,6 @@ GrB_Info GB_serialize               // serialize a matrix into a blob
 void GB_serialize_method
 (
     // output
-    bool *intel,                    // if true, use Intel IPPS (if available)
     int32_t *algo,                  // algorithm to use
     int32_t *level,                 // compression level
     // input
@@ -65,7 +64,6 @@ GrB_Info GB_serialize_array
     GB_void *X,                         // input array of size len
     int64_t len,                        // size of X, in bytes
     int32_t method,                     // compression method requested
-    bool intel,                         // if true, use Intel IPPS
     int32_t algo,                       // compression algorithm
     int32_t level,                      // compression level
     GB_Context Context
@@ -104,12 +102,12 @@ GrB_Info GB_deserialize_from_blob
     int32_t nblocks,            // # of compressed blocks for this array
     int32_t method_used,        // compression method used for each block
     // input/output:
-    size_t *s_handle,           // location to write into the blob
+    size_t *s_handle,           // where to read from the blob
     GB_Context Context
 ) ;
 
 #define GB_BLOB_HEADER_SIZE \
-    sizeof (size_t)             /* blob_size                            */ \
+    sizeof (uint64_t)           /* blob_size                            */ \
     + 11 * sizeof (int64_t)     /* vlen, vdim, nvec, nvec_nonempty,     */ \
                                 /* nvals, typesize, A[phbix]_len        */ \
     + 14 * sizeof (int32_t)     /* version, typecode, sparsity_control, */ \
