@@ -186,22 +186,25 @@
 //------------------------------------------------------------------------------
 // GB_sort
 //------------------------------------------------------------------------------
-    
+
 #undef  GB_FREE_WORKSPACE
 #define GB_FREE_WORKSPACE                   \
 {                                           \
     GB_WERK_POP (C_ek_slicing, int64_t) ;   \
-    GB_phbix_free (T) ;                     \
+    GB_Matrix_free (&T) ;                   \
 }
 
 #undef  GB_FREE_ALL
 #define GB_FREE_ALL                         \
 {                                           \
     GB_FREE_WORKSPACE ;                     \
-    GB_phbix_free (C) ;                     \
-    GB_phbix_free (P) ;                     \
+    if (!C_is_NULL) GB_phybix_free (C) ;    \
+    GB_phybix_free (P) ;                    \
 }
 
+// redefine to use the revised GB_FREE_ALL above:
+#include "GB_static_header.h"
+
 GrB_Info GB_sort
 (
     // output:
@@ -263,10 +266,10 @@ GrB_Info GB_sort
     bool sort_in_place = (A == C) ;
 
     // free any prior content of C and P
-    GB_phbix_free (P) ;
+    GB_phybix_free (P) ;
     if (!sort_in_place)
     { 
-        GB_phbix_free (C) ;
+        GB_phybix_free (C) ;
     }
 
     //--------------------------------------------------------------------------
@@ -276,7 +279,7 @@ GrB_Info GB_sort
     if (C_is_NULL)
     { 
         // C is a temporary matrix, which is freed when done
-        T = GB_clear_static_header (&T_header) ;
+        GB_CLEAR_STATIC_HEADER (T, &T_header) ;
         C = T ;
     }
 
@@ -335,7 +338,7 @@ GrB_Info GB_sort
         }
     }
 
-    // ensure C is sparse or hypersparse CSC
+    // ensure C is sparse or hypersparse
     if (GB_IS_BITMAP (C) || GB_IS_FULL (C))
     { 
         GB_OK (GB_convert_any_to_sparse (C, Context)) ;
@@ -507,13 +510,14 @@ GrB_Info GB_sort
             // C is required on output.  The indices of C are copied and
             // become the values of P.  Cp is copied to Pp, and Ch (if present)
             // is copied to Ph.
-            P->plen = cnvec ;
+            int64_t pplen = GB_IMAX (1, cnvec) ;
+            P->plen = pplen ;
             P->x = GB_MALLOC (cnz, int64_t, &(P->x_size)) ; // x:OK
-            P->p = GB_MALLOC (cnvec+1, int64_t, &(P->p_size)) ;
+            P->p = GB_MALLOC (pplen+1, int64_t, &(P->p_size)) ;
             P->h = NULL ;
             if (C_is_hyper)
             { 
-                P->h = GB_MALLOC (cnvec, int64_t, &(P->h_size)) ;
+                P->h = GB_MALLOC (pplen, int64_t, &(P->h_size)) ;
             }
             if (P->x == NULL || P->p == NULL || (C_is_hyper && P->h == NULL))
             { 
@@ -531,6 +535,7 @@ GrB_Info GB_sort
             }
         }
 
+        P->nvals = cnz ;
         P->magic = GB_MAGIC ;
     }
 
@@ -545,12 +550,22 @@ GrB_Info GB_sort
     }
 
     //--------------------------------------------------------------------------
-    // free workspace and return result
+    // free workspace, and comform/return result
     //--------------------------------------------------------------------------
 
     GB_FREE_WORKSPACE ;
-    if (!C_is_NULL) { ASSERT_MATRIX_OK (C, "C output of GB_sort", GB0) ; }
-    if (P != NULL)  { ASSERT_MATRIX_OK (P, "P output of GB_sort", GB0) ; }
+    if (!C_is_NULL)
+    { 
+        ASSERT_MATRIX_OK (C, "C output of GB_sort (before conform)", GB0) ;
+        GB_OK (GB_conform (C, Context)) ;
+        ASSERT_MATRIX_OK (C, "C output of GB_sort", GB0) ;
+    }
+    if (P != NULL)
+    { 
+        ASSERT_MATRIX_OK (P, "P output of GB_sort (before conform)", GB0) ;
+        GB_OK (GB_conform (P, Context)) ;
+        ASSERT_MATRIX_OK (P, "P output of GB_sort", GB0) ;
+    }
     return (GrB_SUCCESS) ;
 }
 
