@@ -57,6 +57,7 @@ GrB_Info GB_subassign_06s_and_14
     //--------------------------------------------------------------------------
 
     GB_EMPTY_TASKLIST ;
+    GB_CLEAR_STATIC_HEADER (S, &S_header) ;
     GB_OK (GB_subassign_symbolic (S, C, I, ni, J, nj, true, Context)) ;
 
     //--------------------------------------------------------------------------
@@ -73,6 +74,7 @@ GrB_Info GB_subassign_06s_and_14
 
     GB_GET_C ;      // C must not be bitmap
     GB_GET_MASK ;
+    GB_GET_MASK_HYPER_HASH ;
     GB_GET_A ;
     GB_GET_S ;
     GrB_BinaryOp accum = NULL ;
@@ -143,7 +145,7 @@ GrB_Info GB_subassign_06s_and_14
                 // get S(iA_start:iA_end,j)
                 //--------------------------------------------------------------
 
-                GB_GET_VECTOR_FOR_IXJ (S, iA_start) ;
+                GB_LOOKUP_VECTOR_FOR_IXJ (S, iA_start) ;
                 int64_t pA_start = j * Avlen ;
 
                 //--------------------------------------------------------------
@@ -151,7 +153,7 @@ GrB_Info GB_subassign_06s_and_14
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -250,7 +252,7 @@ GrB_Info GB_subassign_06s_and_14
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -386,7 +388,7 @@ GrB_Info GB_subassign_06s_and_14
                 // get S(iA_start:iA_end,j)
                 //--------------------------------------------------------------
 
-                GB_GET_VECTOR_FOR_IXJ (S, iA_start) ;
+                GB_LOOKUP_VECTOR_FOR_IXJ (S, iA_start) ;
                 int64_t pA_start = j * Avlen ;
 
                 //--------------------------------------------------------------
@@ -394,7 +396,7 @@ GrB_Info GB_subassign_06s_and_14
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -471,7 +473,7 @@ GrB_Info GB_subassign_06s_and_14
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
