@@ -58,6 +58,7 @@ GrB_Info GB_subassign_12_and_20
     //--------------------------------------------------------------------------
 
     GB_EMPTY_TASKLIST ;
+    GB_CLEAR_STATIC_HEADER (S, &S_header) ;
     GB_OK (GB_subassign_symbolic (S, C, I, ni, J, nj, true, Context)) ;
 
     //--------------------------------------------------------------------------
@@ -69,6 +70,7 @@ GrB_Info GB_subassign_12_and_20
 
     GB_GET_C ;      // C must not be bitmap
     GB_GET_MASK ;
+    GB_GET_MASK_HYPER_HASH ;
     GB_GET_A ;
     GB_GET_S ;
     GB_GET_ACCUM ;
@@ -130,7 +132,7 @@ GrB_Info GB_subassign_12_and_20
                 // get S(iA_start:iA_end,j)
                 //--------------------------------------------------------------
 
-                GB_GET_VECTOR_FOR_IXJ (S, iA_start) ;
+                GB_LOOKUP_VECTOR_FOR_IXJ (S, iA_start) ;
                 int64_t pA_start = j * Avlen ;
 
                 //--------------------------------------------------------------
@@ -138,7 +140,7 @@ GrB_Info GB_subassign_12_and_20
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -245,7 +247,7 @@ GrB_Info GB_subassign_12_and_20
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -388,7 +390,7 @@ GrB_Info GB_subassign_12_and_20
                 // get S(iA_start:iA_end,j)
                 //--------------------------------------------------------------
 
-                GB_GET_VECTOR_FOR_IXJ (S, iA_start) ;
+                GB_LOOKUP_VECTOR_FOR_IXJ (S, iA_start) ;
                 int64_t pA_start = j * Avlen ;
 
                 //--------------------------------------------------------------
@@ -396,7 +398,7 @@ GrB_Info GB_subassign_12_and_20
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
@@ -473,7 +475,7 @@ GrB_Info GB_subassign_12_and_20
                 //--------------------------------------------------------------
 
                 int64_t pM_start, pM_end ;
-                GB_VECTOR_LOOKUP (pM_start, pM_end, M, j) ;
+                GB_LOOKUP_VECTOR (pM_start, pM_end, M, j) ;
                 bool mjdense = (pM_end - pM_start) == Mvlen ;
 
                 //--------------------------------------------------------------
