@@ -2,7 +2,7 @@
 // GB_subref_phase0: find vectors of C = A(I,J) and determine I,J properties
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
@@ -145,6 +145,14 @@ static inline void GB_find_Ap_start_end
     GB_WERK_POP (Count, int64_t) ;  \
 }
 
+#define GB_FREE_ALL                             \
+{                                               \
+    GB_FREE_WORKSPACE ;                         \
+    GB_FREE (&Ch, Ch_size) ;                    \
+    GB_FREE_WORK (&Ap_start, Ap_start_size) ;   \
+    GB_FREE_WORK (&Ap_end, Ap_end_size) ;       \
+}
+
 GrB_Info GB_subref_phase0
 (
     // output
@@ -190,6 +198,10 @@ GrB_Info GB_subref_phase0
     ASSERT (J != NULL) ;
 
     GrB_Info info ;
+    GB_WERK_DECLARE (Count, int64_t) ;
+    int64_t *restrict Ch       = NULL ; size_t Ch_size = 0 ;
+    int64_t *restrict Ap_start = NULL ; size_t Ap_start_size = 0 ;
+    int64_t *restrict Ap_end   = NULL ; size_t Ap_end_size = 0 ;
 
     (*p_Ch        ) = NULL ;
     (*p_Ap_start  ) = NULL ;
@@ -248,9 +260,10 @@ GrB_Info GB_subref_phase0
     //--------------------------------------------------------------------------
 
     bool C_empty = (nI == 0 || nJ == 0) ;
+    bool A_is_hyper = (Ah != NULL) ;
 
     //--------------------------------------------------------------------------
-    // trim the hyperlist of A
+    // trim the hyperlist of A for (J = jbegin:jend case only)
     //--------------------------------------------------------------------------
 
     // Ah, Ap, and anvec are modified to include just the vectors in range
@@ -259,9 +272,7 @@ GrB_Info GB_subref_phase0
     // jmax is avdim-1, so there is nothing to trim from Ah.  If C is empty,
     // then Ah and Ap will not be accessed at all, so this can be skipped.
 
-    bool A_is_hyper = (Ah != NULL) ;
-
-    if (A_is_hyper && !C_empty)
+    if (!C_empty && A_is_hyper && Jkind == GB_RANGE)
     {
 
         //----------------------------------------------------------------------
@@ -299,6 +310,26 @@ GrB_Info GB_subref_phase0
     // Ah may now be empty, after being trimmed
     C_empty = C_empty || (anvec == 0) ;
 
+    //--------------------------------------------------------------------------
+    // build the hyper_hash, if needed
+    //--------------------------------------------------------------------------
+
+    bool J_is_all_or_range = (Jkind == GB_ALL || Jkind == GB_RANGE) ;
+    bool J_is_long_stride = (Jkind == GB_STRIDE && anvec < nJ * 64) ;
+
+    bool use_hyper_hash = !C_empty && A_is_hyper &&
+            !J_is_all_or_range && !J_is_long_stride &&
+            (A->Y != NULL || nJ > anvec) ;
+    if (use_hyper_hash)
+    { 
+        GB_OK (GB_hyper_hash_build (A, Context)) ;
+    }
+
+    const int64_t *restrict A_Yp = (use_hyper_hash) ? A->Y->p : NULL ;
+    const int64_t *restrict A_Yi = (use_hyper_hash) ? A->Y->i : NULL ;
+    const int64_t *restrict A_Yx = (use_hyper_hash) ? A->Y->x : NULL ;
+    const int64_t A_hash_bits = (use_hyper_hash) ? (A->Y->vdim - 1) : 0 ;
+
     //--------------------------------------------------------------------------
     // determine # of threads to use
     //--------------------------------------------------------------------------
@@ -320,11 +351,11 @@ GrB_Info GB_subref_phase0
     // allocate workspace
     //--------------------------------------------------------------------------
 
-    GB_WERK_DECLARE (Count, int64_t) ;
     GB_WERK_PUSH (Count, ntasks_max+1, int64_t) ;
     if (Count == NULL)
     { 
         // out of memory
+        GB_FREE_ALL ;
         return (GrB_OUT_OF_MEMORY) ;
     }
 
@@ -336,9 +367,6 @@ GrB_Info GB_subref_phase0
     // if C(:,jC) is the (kC)th vector of C.  If NULL, then C is standard, and
     // jC == kC.  jC is in the range 0 to nJ-1.
 
-    int64_t *restrict Ch       = NULL ; size_t Ch_size = 0 ;
-    int64_t *restrict Ap_start = NULL ; size_t Ap_start_size = 0 ;
-    int64_t *restrict Ap_end   = NULL ; size_t Ap_end_size = 0 ;
     int64_t Cnvec = 0 ;
 
     int64_t jbegin = Jcolon [GxB_BEGIN] ;
@@ -365,13 +393,14 @@ GrB_Info GB_subref_phase0
         GB_GET_NTHREADS_AND_NTASKS (nJ) ;
 
     }
-    else if (Jkind == GB_ALL || Jkind == GB_RANGE)
+    else if (J_is_all_or_range) // (Jkind == GB_ALL || Jkind == GB_RANGE)
     { 
 
         //----------------------------------------------------------------------
         // J is ":" or jbegin:jend
         //----------------------------------------------------------------------
 
+        // For the case where J is jbegin:jend, Ah has been trimmed (see above).
         // Ch is a shifted copy of the trimmed Ah, of length Cnvec = anvec.  
         // so kA = kC, and jC = Ch [kC] = jA - jmin.  Ap has also been trimmed.
 
@@ -380,7 +409,7 @@ GrB_Info GB_subref_phase0
         GB_GET_NTHREADS_AND_NTASKS (anvec) ;
 
     }
-    else if (Jkind == GB_STRIDE && anvec < nJ * 64)
+    else if (J_is_long_stride) // (Jkind == GB_STRIDE && anvec < nJ * 64)
     {
 
         //----------------------------------------------------------------------
@@ -437,20 +466,37 @@ GrB_Info GB_subref_phase0
         GB_GET_NTHREADS_AND_NTASKS (nJ) ;
 
         // scan all of J and check each entry if it appears in Ah
+
         int tid ;
         #pragma omp parallel for num_threads(nthreads) schedule(dynamic,1)
         for (tid = 0 ; tid < ntasks ; tid++)
         {
-            int64_t jC_start, jC_end, my_Cnvec = 0 ;
+            int64_t jC_start, jC_end ;
             GB_PARTITION (jC_start, jC_end, nJ, tid, ntasks) ;
+            int64_t my_Cnvec = 0 ;
             for (int64_t jC = jC_start ; jC < jC_end ; jC++)
-            { 
+            {
                 int64_t jA = GB_ijlist (J, jC, Jkind, Jcolon) ;
                 bool found ;
                 int64_t kA = 0 ;
-                int64_t kright = anvec-1 ;
-                GB_BINARY_SEARCH (jA, Ah, kA, kright, found) ;
-                if (found) my_Cnvec++ ;
+                if (use_hyper_hash)
+                { 
+                    // find jA using the hyper_hash
+                    int64_t ignore1, ignore2 ;
+                    kA = GB_hyper_hash_lookup (Ap, A_Yp, A_Yi, A_Yx,
+                        A_hash_bits, jA, &ignore1, &ignore2) ;
+                    found = (kA >= 0) ;
+                }
+                else
+                { 
+                    // find jA using binary search
+                    int64_t kright = anvec-1 ;
+                    GB_BINARY_SEARCH (jA, Ah, kA, kright, found) ;
+                }
+                if (found)
+                { 
+                    my_Cnvec++ ;
+                }
             }
             Count [tid] = my_Cnvec ;
         }
@@ -473,7 +519,7 @@ GrB_Info GB_subref_phase0
         Ch = GB_MALLOC (Cnvec, int64_t, &Ch_size) ;
         if (Ch == NULL)
         { 
-            GB_FREE_WORKSPACE ;
+            GB_FREE_ALL ;
             return (GrB_OUT_OF_MEMORY) ;
         }
     }
@@ -485,10 +531,7 @@ GrB_Info GB_subref_phase0
         if (Ap_start == NULL || Ap_end == NULL)
         { 
             // out of memory
-            GB_FREE_WORKSPACE ;
-            GB_FREE (&Ch, Ch_size) ;
-            GB_FREE_WORK (&Ap_start, Ap_start_size) ;
-            GB_FREE_WORK (&Ap_end, Ap_end_size) ;
+            GB_FREE_ALL ;
             return (GrB_OUT_OF_MEMORY) ;
         }
     }
@@ -528,7 +571,7 @@ GrB_Info GB_subref_phase0
         }
 
     }
-    else if (Jkind == GB_ALL || Jkind == GB_RANGE)
+    else if (J_is_all_or_range) // (Jkind == GB_ALL || Jkind == GB_RANGE)
     {
 
         //----------------------------------------------------------------------
@@ -551,7 +594,7 @@ GrB_Info GB_subref_phase0
         }
 
     }
-    else if (Jkind == GB_STRIDE && anvec < nJ * 64)
+    else if (J_is_long_stride) // (Jkind == GB_STRIDE && anvec < nJ * 64)
     {
 
         //----------------------------------------------------------------------
@@ -633,8 +676,20 @@ GrB_Info GB_subref_phase0
                 int64_t jA = GB_ijlist (J, jC, Jkind, Jcolon) ;
                 bool found ;
                 int64_t kA = 0 ;
-                int64_t kright = anvec-1 ;
-                GB_BINARY_SEARCH (jA, Ah, kA, kright, found) ;
+                if (use_hyper_hash)
+                { 
+                    // find jA using the hyper_hash
+                    int64_t ignore1, ignore2 ;
+                    kA = GB_hyper_hash_lookup (Ap, A_Yp, A_Yi, A_Yx,
+                        A_hash_bits, jA, &ignore1, &ignore2) ;
+                    found = (kA >= 0) ;
+                }
+                else
+                { 
+                    // find jA using binary search
+                    int64_t kright = anvec-1 ;
+                    GB_BINARY_SEARCH (jA, Ah, kA, kright, found) ;
+                }
                 if (found)
                 { 
                     ASSERT (jA == Ah [kA]) ;
@@ -661,8 +716,8 @@ GrB_Info GB_subref_phase0
         int64_t kA = 0 ;
         int64_t pright = A->nvec - 1 ;
         int64_t pA_start_all, pA_end_all ;
-        bool found = GB_lookup (A->h != NULL, A->h, A->p, A->vlen, &kA,
-            pright, jA, &pA_start_all, &pA_end_all) ;
+        bool found = GB_lookup (A->h != NULL,   // for debug only
+            A->h, A->p, A->vlen, &kA, pright, jA, &pA_start_all, &pA_end_all) ;
         if (found && A->h != NULL)
         {
             ASSERT (jA == A->h [kA]) ;
