@@ -17,12 +17,8 @@
 
 GrB_Info GrB_Descriptor_wait // no work, just check if GrB_Descriptor is valid
 (
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GrB_Descriptor *desc     // required; may not be NULL a pointer to NULL
-    #else
     GrB_Descriptor desc,
     GrB_WaitMode waitmode
-    #endif
 )
 {
 
@@ -30,13 +26,8 @@ GrB_Info GrB_Descriptor_wait // no work, just check if GrB_Descriptor is valid
     // check inputs
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GB_WHERE1 ("GrB_Descriptor_wait (&desc)") ;
-    if (desc != NULL && (*desc) != NULL) GB_RETURN_IF_FAULTY (*desc) ;
-    #else
     GB_WHERE1 ("GrB_Descriptor_wait (desc, waitmode)") ;
     if (desc != NULL) GB_RETURN_IF_FAULTY (desc) ;
-    #endif
 
     //--------------------------------------------------------------------------
     // return result
