@@ -2,7 +2,7 @@
 // GrB_IndexUnaryOp_new: create a new user-defined index_unary operator
 //------------------------------------------------------------------------------
 
-// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2021, All Rights Reserved.
+// SuiteSparse:GraphBLAS, Timothy A. Davis, (c) 2017-2022, All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
 //------------------------------------------------------------------------------
@@ -17,16 +17,16 @@
 #undef GrB_IndexUnaryOp_new
 #undef GrM_IndexUnaryOp_new
 
-GrB_Info GRB (IndexUnaryOp_new)
+GrB_Info GRB (IndexUnaryOp_new)     // create a new user-defined IndexUnary op
 (
-    GrB_IndexUnaryOp *op,         // handle for the new index_unary operator
-    GxB_index_unary_function function,   // pointer to the index_unary function
+    GrB_IndexUnaryOp *op,           // handle for the new IndexUnary operator
+    GxB_index_unary_function function,    // pointer to IndexUnary function
     GrB_Type ztype,                 // type of output z
-    GrB_Type xtype,                 // type of input x
-    GrB_Type ttype                  // type of input thunk
+    GrB_Type xtype,                 // type of input x (the A(i,j) entry)
+    GrB_Type ytype                  // type of input y (the scalar)
 )
 { 
-    return (GxB_IndexUnaryOp_new (op, function, ztype, xtype, ttype,
+    return (GxB_IndexUnaryOp_new (op, function, ztype, xtype, ytype,
         NULL, NULL)) ;
 }
 
