@@ -266,8 +266,8 @@ static GrB_Info GB_import_worker   // import a matrix of any type
                 int64_t vdim = is_csc ? ncols : nrows ;
 
                 // allocate the header for A
-                GB_OK (GB_new (A, false, type,  // new header
-                    vlen, vdim, GB_Ap_null, is_csc, GxB_AUTO_SPARSITY,
+                GB_OK (GB_new (A, // new header
+                    type, vlen, vdim, GB_Ap_null, is_csc, GxB_AUTO_SPARSITY,
                     GB_Global_hyper_switch_get ( ), 0, Context)) ;
 
                 // build A from the input triplets
@@ -294,6 +294,7 @@ static GrB_Info GB_import_worker   // import a matrix of any type
                     nvals,          // number of tuples
                     NULL,           // implicit SECOND operator for duplicates
                     type,           // type of the X array
+                    true,           // burble is allowed
                     Context
                 )) ;
             }
