@@ -15,12 +15,8 @@
 
 GrB_Info GrB_Matrix_wait    // finish all work on a matrix
 (
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GrB_Matrix *A
-    #else
     GrB_Matrix A,
     GrB_WaitMode waitmode
-    #endif
 )
 { 
 
@@ -28,36 +24,22 @@ GrB_Info GrB_Matrix_wait    // finish all work on a matrix
     // check inputs
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GB_WHERE ((*A), "GrB_Matrix_wait (&A)") ;
-    GB_RETURN_IF_NULL (A) ;
-    GB_RETURN_IF_NULL_OR_FAULTY (*A) ;
-    #else
     GB_WHERE (A, "GrB_Matrix_wait (A, waitmode)") ;
     GB_RETURN_IF_NULL_OR_FAULTY (A) ;
-    #endif
 
     //--------------------------------------------------------------------------
-    // finish all pending work on the matrix
+    // finish all pending work on the matrix, including creating A->Y
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    if (GB_ANY_PENDING_WORK (*A))
-    {
-        GrB_Info info ;
-        GB_BURBLE_START ("GrB_Matrix_wait") ;
-        GB_OK (GB_wait (*A, "matrix", Context)) ;
-        GB_BURBLE_END ;
-    }
-    #else
-    if (waitmode != GrB_COMPLETE && GB_ANY_PENDING_WORK (A))
+    if (waitmode != GrB_COMPLETE &&
+        (GB_ANY_PENDING_WORK (A) || GB_NEED_HYPER_HASH (A)))
     {
         GrB_Info info ;
         GB_BURBLE_START ("GrB_Matrix_wait") ;
         GB_OK (GB_wait (A, "matrix", Context)) ;
+        GB_OK (GB_hyper_hash_build (A, Context)) ;
         GB_BURBLE_END ;
     }
-    #endif
 
     //--------------------------------------------------------------------------
     // return result
