@@ -15,12 +15,8 @@
 
 GrB_Info GrB_Scalar_wait    // finish all work on a scalar
 (
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GrB_Scalar *s
-    #else
     GrB_Scalar s,
     GrB_WaitMode waitmode
-    #endif
 )
 { 
 
@@ -28,28 +24,13 @@ GrB_Info GrB_Scalar_wait    // finish all work on a scalar
     // check inputs
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GB_WHERE ((*s), "GrB_Scalar_wait (&s)") ;
-    GB_RETURN_IF_NULL (s) ;
-    GB_RETURN_IF_NULL_OR_FAULTY (*s) ;
-    #else
     GB_WHERE (s, "GrB_Scalar_wait (s, waitmode)") ;
     GB_RETURN_IF_NULL_OR_FAULTY (s) ;
-    #endif
 
     //--------------------------------------------------------------------------
     // finish all pending work on the scalar
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    if (GB_ANY_PENDING_WORK (*s))
-    {
-        GrB_Info info ;
-        GB_BURBLE_START ("GrB_Scalar_wait") ;
-        GB_OK (GB_wait ((GrB_Matrix) (*s), "scalar", Context)) ;
-        GB_BURBLE_END ;
-    }
-    #else
     if (waitmode != GrB_COMPLETE && GB_ANY_PENDING_WORK (s))
     {
         GrB_Info info ;
@@ -57,7 +38,6 @@ GrB_Info GrB_Scalar_wait    // finish all work on a scalar
         GB_OK (GB_wait ((GrB_Matrix) s, "scalar", Context)) ;
         GB_BURBLE_END ;
     }
-    #endif
 
     //--------------------------------------------------------------------------
     // return result
@@ -76,10 +56,6 @@ GrB_Info GxB_Scalar_wait    // finish all work on a scalar
     GrB_Scalar *s
 )
 {
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    return (GrB_Scalar_wait (s)) ;
-    #else
     return (GrB_Scalar_wait (*s, GrB_MATERIALIZE)) ;
-    #endif
 }
 
