@@ -15,12 +15,8 @@
 
 GrB_Info GrB_UnaryOp_wait   // no work, just check if the GrB_UnaryOp is valid
 (
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GrB_UnaryOp *op
-    #else
     GrB_UnaryOp op,
     GrB_WaitMode waitmode
-    #endif
 )
 { 
 
@@ -28,14 +24,8 @@ GrB_Info GrB_UnaryOp_wait   // no work, just check if the GrB_UnaryOp is valid
     // check inputs
     //--------------------------------------------------------------------------
 
-    #if (GxB_IMPLEMENTATION_MAJOR <= 5)
-    GB_WHERE1 ("GrB_UnaryOp_wait (&op)") ;
-    GB_RETURN_IF_NULL (op) ;
-    GB_RETURN_IF_NULL_OR_FAULTY (*op) ;
-    #else
     GB_WHERE1 ("GrB_UnaryOp_wait (op, waitmode)") ;
     GB_RETURN_IF_NULL_OR_FAULTY (op) ;
-    #endif
 
     //--------------------------------------------------------------------------
     // return result
