@@ -44,7 +44,7 @@ GrB_Info GrB_Vector_new     // create a new vector with no entries
     GrB_Info info ;
     int64_t vlen = (int64_t) n ;
 
-    info = GB_new ((GrB_Matrix *) v, false, // new user header
+    info = GB_new ((GrB_Matrix *) v, // new user header
         type, vlen, 1, GB_Ap_calloc,
         true,  // a GrB_Vector is always held by-column
         GxB_SPARSE, GB_Global_hyper_switch_get ( ), 1, Context) ;
