@@ -10,6 +10,7 @@
 // Set a single scalar, w(row) = x, typecasting from the type of x to
 // the type of w as needed.
 
+#define GB_FREE_ALL ;
 #include "GB.h"
 
 #define GB_SET(prefix,type,T,ampersand)                                     \
@@ -23,7 +24,7 @@ GrB_Info GB_EVAL3 (prefix, _Vector_setElement_, T)    /* w(row) = x */      \
     GB_WHERE (w, "GrB_Vector_setElement_" GB_STR(T) " (w, x, row)") ;       \
     GB_RETURN_IF_NULL_OR_FAULTY (w) ;                                       \
     ASSERT (GB_VECTOR_OK (w)) ;                                             \
-    return (GB_setElement ((GrB_Matrix) w, ampersand x, row, 0,             \
+    return (GB_setElement ((GrB_Matrix) w, NULL, ampersand x, row, 0,       \
         GB_ ## T ## _code, Context)) ;                                      \
 }
 
@@ -71,10 +72,12 @@ GrB_Info GrB_Vector_setElement_Scalar
     // set or remove the element
     //--------------------------------------------------------------------------
 
+    GrB_Info info ;
+    GB_MATRIX_WAIT (scalar) ;
     if (GB_nnz ((GrB_Matrix) scalar) > 0)
     { 
         // set the element: w(row) = scalar
-        return (GB_setElement ((GrB_Matrix) w, scalar->x, row, 0,
+        return (GB_setElement ((GrB_Matrix) w, NULL, scalar->x, row, 0,
             scalar->type->code, Context)) ;
     }
     else
